@@ -28,18 +28,18 @@ def test_set_key_no_file(tmp_path):
 @pytest.mark.parametrize(
     "before,key,value,expected,after",
     [
-        ("", "a", "", (True, "a", ""), 'a=""\n'),
-        ("", "a", "b", (True, "a", "b"), 'a="b"\n'),
-        ("", "a", "'b'", (True, "a", "b"), 'a="b"\n'),
-        ("", "a", "\"b\"", (True, "a", "b"), 'a="b"\n'),
-        ("", "a", "b'c", (True, "a", "b'c"), 'a="b\'c"\n'),
-        ("", "a", "b\"c", (True, "a", "b\"c"), 'a="b\\\"c"\n'),
-        ("a=b", "a", "c", (True, "a", "c"), 'a="c"\n'),
-        ("a=b\n", "a", "c", (True, "a", "c"), 'a="c"\n'),
-        ("a=b\n\n", "a", "c", (True, "a", "c"), 'a="c"\n\n'),
-        ("a=b\nc=d", "a", "e", (True, "a", "e"), 'a="e"\nc=d'),
-        ("a=b\nc=d\ne=f", "c", "g", (True, "c", "g"), 'a=b\nc="g"\ne=f'),
-        ("a=b\n", "c", "d", (True, "c", "d"), 'a=b\nc="d"\n'),
+        ("", "a", "", (True, "a", ""), "a=''\n"),
+        ("", "a", "b", (True, "a", "b"), "a='b'\n"),
+        ("", "a", "'b'", (True, "a", "'b'"), "a='\\'b\\''\n"),
+        ("", "a", "\"b\"", (True, "a", '"b"'), "a='\"b\"'\n"),
+        ("", "a", "b'c", (True, "a", "b'c"), "a='b\\'c'\n"),
+        ("", "a", "b\"c", (True, "a", "b\"c"), "a='b\"c'\n"),
+        ("a=b", "a", "c", (True, "a", "c"), "a='c'\n"),
+        ("a=b\n", "a", "c", (True, "a", "c"), "a='c'\n"),
+        ("a=b\n\n", "a", "c", (True, "a", "c"), "a='c'\n\n"),
+        ("a=b\nc=d", "a", "e", (True, "a", "e"), "a='e'\nc=d"),
+        ("a=b\nc=d\ne=f", "c", "g", (True, "c", "g"), "a=b\nc='g'\ne=f"),
+        ("a=b\n", "c", "d", (True, "c", "d"), "a=b\nc='d'\n"),
     ],
 )
 def test_set_key(dotenv_file, before, key, value, expected, after):
@@ -257,6 +257,28 @@ def test_load_dotenv_existing_variable_override(dotenv_file):
     assert os.environ == {"a": "b"}
 
 
+@mock.patch.dict(os.environ, {"a": "c"}, clear=True)
+def test_load_dotenv_redefine_var_used_in_file_no_override(dotenv_file):
+    with open(dotenv_file, "w") as f:
+        f.write('a=b\nd="${a}"')
+
+    result = dotenv.load_dotenv(dotenv_file)
+
+    assert result is True
+    assert os.environ == {"a": "c", "d": "c"}
+
+
+@mock.patch.dict(os.environ, {"a": "c"}, clear=True)
+def test_load_dotenv_redefine_var_used_in_file_with_override(dotenv_file):
+    with open(dotenv_file, "w") as f:
+        f.write('a=b\nd="${a}"')
+
+    result = dotenv.load_dotenv(dotenv_file, override=True)
+
+    assert result is True
+    assert os.environ == {"a": "b", "d": "b"}
+
+
 @mock.patch.dict(os.environ, {}, clear=True)
 def test_load_dotenv_utf_8():
     stream = StringIO("a=à")
